@@ -2,7 +2,6 @@ import argparse
 import glob
 import json
 import os
-import sys
 from dataclasses import dataclass, field, fields
 from enum import Enum
 from pathlib import Path
@@ -30,10 +29,12 @@ class CliAction(Enum):
     version = "version"
     check = "check"
     update = "update"
+    clean = "clean"
 
 
 @dataclass
 class Config:
+    no_stderr: bool = False
     recursive: bool = False
     to_be_deleted: list[str] = field(default_factory=list)
     pipe: bool = False
@@ -54,21 +55,24 @@ class Config:
     query_multiplier: int = -1
     query_exclude: list[PathLike] = field(default_factory=list)
     reranker: Optional[str] = None
+    reranker_params: dict[str, Any] = field(default_factory=dict)
     check_item: Optional[str] = None
+    use_absolute_path: bool = False
 
     @classmethod
     async def import_from(cls, config_dict: dict[str, Any]) -> "Config":
+        """
+        Raise IOError if db_path is not valid.
+        """
         db_path = config_dict.get("db_path")
         host = config_dict.get("host") or "localhost"
         port = config_dict.get("port") or 8000
         if db_path is None:
             db_path = os.path.expanduser("~/.local/share/vectorcode/chromadb/")
         elif not os.path.isdir(db_path):
-            print(
-                f"{str(db_path)} is not a valid directory!",
-                file=sys.stderr,
+            raise IOError(
+                f"The configured db_path ({str(db_path)}) is not a valid directory."
             )
-            sys.exit(1)
         return Config(
             **{
                 "embedding_function": config_dict.get(
@@ -82,6 +86,7 @@ class Config:
                 "overlap_ratio": config_dict.get("overlap_ratio", 0.2),
                 "query_multiplier": config_dict.get("query_multiplier", -1),
                 "reranker": config_dict.get("reranker", None),
+                "reranker_params": config_dict.get("reranker_params", {}),
                 "db_settings": config_dict.get("db_settings", None),
             }
         )
@@ -124,6 +129,12 @@ async def cli_arg_parser():
         default=False,
         help="Print structured output for other programs to process.",
     )
+    shared_parser.add_argument(
+        "--no_stderr",
+        action="store_true",
+        default=False,
+        help="Supress all STDERR messages.",
+    )
     main_parser = argparse.ArgumentParser(
         "vectorcode",
         parents=[shared_parser],
@@ -180,14 +191,27 @@ async def cli_arg_parser():
     query_parser.add_argument(
         "--exclude", nargs="*", help="Files to exclude from query results."
     ).complete = shtab.FILE
+    query_parser.add_argument(
+        "--absolute",
+        default=False,
+        action="store_true",
+        help="Use absolute path when returning the retrieval results.",
+    )
 
     subparsers.add_parser("drop", parents=[shared_parser], help="Remove a collection.")
 
-    subparsers.add_parser(
+    init_parser = subparsers.add_parser(
         "init",
         parents=[shared_parser],
         help="Initialise a directory as VectorCode project root.",
     )
+    init_parser.add_argument(
+        "--force",
+        "-f",
+        action="store_true",
+        default=False,
+        help="Wipe current project config and overwrite with global config (if it exists).",
+    )
 
     subparsers.add_parser(
         "version", parents=[shared_parser], help="Print the version number."
@@ -209,6 +233,12 @@ async def cli_arg_parser():
         help="Update embeddings in the database for indexed files.",
     )
 
+    subparsers.add_parser(
+        "clean",
+        parents=[shared_parser],
+        help="Remove empty collections in the database.",
+    )
+
     main_args = main_parser.parse_args()
     if main_args.action is None:
         main_args = main_parser.parse_args(["--help"])
@@ -223,6 +253,7 @@ async def cli_arg_parser():
     query_multiplier = -1
     query_exclude = []
     check_item = None
+    absolute = False
     match main_args.action:
         case "vectorise":
             files = main_args.file_paths
@@ -235,9 +266,13 @@ async def cli_arg_parser():
             number_of_result = main_args.number
             query_multiplier = main_args.multiplier
             query_exclude = main_args.exclude
+            absolute = main_args.absolute
         case "check":
             check_item = main_args.check_item
+        case "init":
+            force = main_args.force
     return Config(
+        no_stderr=main_args.no_stderr,
         action=CliAction(main_args.action),
         files=files,
         project_root=main_args.project_root,
@@ -251,6 +286,7 @@ async def cli_arg_parser():
         query_multiplier=query_multiplier,
         query_exclude=query_exclude,
         check_item=check_item,
+        use_absolute_path=absolute,
     )
 
 
