@@ -4,7 +4,7 @@ import os
 import socket
 import subprocess
 import sys
-from typing import Any, Coroutine
+from typing import Any, AsyncGenerator, Coroutine
 
 import chromadb
 import httpx
@@ -16,11 +16,31 @@ from chromadb.utils import embedding_functions
 from vectorcode.cli_utils import Config, expand_path
 
 
-def try_server(host: str, port: int):
+async def get_collections(client: AsyncClientAPI) -> AsyncGenerator[AsyncCollection]:
+    for collection_name in await client.list_collections():
+        collection = await client.get_collection(collection_name)
+        meta = collection.metadata
+        if meta is None:
+            continue
+        if meta.get("created-by") != "VectorCode":
+            continue
+        if meta.get("username") not in (
+            os.environ.get("USER"),
+            os.environ.get("USERNAME"),
+            "DEFAULT_USER",
+        ):
+            continue
+        if meta.get("hostname") != socket.gethostname():
+            continue
+        yield collection
+
+
+async def try_server(host: str, port: int):
     url = f"http://{host}:{port}/api/v1/heartbeat"
     try:
-        with httpx.Client() as client:
-            return client.get(url=url).status_code == 200
+        async with httpx.AsyncClient() as client:
+            response = await client.get(url=url)
+            return response.status_code == 200
     except (httpx.ConnectError, httpx.ConnectTimeout):
         return False
 
@@ -58,21 +78,19 @@ async def start_server(configs: Config):
         s.bind(("", 0))  # OS selects a free ephemeral port
         configs.port = int(s.getsockname()[1])
     env.update({"ANONYMIZED_TELEMETRY": "False"})
-    process = subprocess.Popen(
-        [
-            sys.executable,
-            "-m",
-            "chromadb.cli.cli",
-            "run",
-            "--host",
-            "localhost",
-            "--port",
-            str(configs.port),
-            "--path",
-            db_path,
-            "--log-path",
-            os.path.join(str(configs.project_root), "chroma.log"),
-        ],
+    process = await asyncio.create_subprocess_exec(
+        sys.executable,
+        "-m",
+        "chromadb.cli.cli",
+        "run",
+        "--host",
+        "localhost",
+        "--port",
+        str(configs.port),
+        "--path",
+        db_path,
+        "--log-path",
+        os.path.join(str(configs.project_root), "chroma.log"),
         stdout=subprocess.DEVNULL,
         stderr=sys.stderr,
         env=env,
@@ -86,20 +104,17 @@ def get_client(configs: Config) -> Coroutine[Any, Any, AsyncClientAPI]:
     assert configs.host is not None
     assert configs.port is not None
     assert configs.db_path is not None
-    try:
-        settings = {"anonymized_telemetry": False}
-        if isinstance(configs.db_settings, dict):
-            settings.update(configs.db_settings)
-        return chromadb.AsyncHttpClient(
-            host=configs.host or "localhost",
-            port=configs.port or 8000,
-            settings=Settings(**settings),
-        )
-    except ValueError:
-        print(
-            f"Failed to access the chromadb server at {configs.host}:{configs.port}. Please verify your setup and configurations."
-        )
-        sys.exit(1)
+    settings = {"anonymized_telemetry": False}
+    if isinstance(configs.db_settings, dict):
+        valid_settings = {
+            k: v for k, v in configs.db_settings.items() if k in Settings.__fields__
+        }
+        settings.update(valid_settings)
+    return chromadb.AsyncHttpClient(
+        host=configs.host or "localhost",
+        port=configs.port or 8000,
+        settings=Settings(**settings),
+    )
 
 
 def get_collection_name(full_path: str) -> str:
@@ -122,7 +137,6 @@ def get_embedding_function(configs: Config) -> chromadb.EmbeddingFunction:
             f"Failed to use {configs.embedding_function}. Falling back to Sentence Transformer.",
             file=sys.stderr,
         )
-    finally:
         return embedding_functions.SentenceTransformerEmbeddingFunction()
 
 
