@@ -1,5 +1,4 @@
 import asyncio
-import atexit
 import logging
 import os
 import sys
@@ -14,16 +13,22 @@ from vectorcode.cli_utils import (
     load_config_file,
 )
 from vectorcode.common import start_server, try_server
-from vectorcode.subcommands import check, drop, init, ls, query, update, vectorise
+from vectorcode.subcommands import (
+    check,
+    clean,
+    drop,
+    init,
+    ls,
+    query,
+    update,
+    vectorise,
+)
 
 
 async def async_main():
     cli_args = await cli_arg_parser()
     if cli_args.no_stderr:
         sys.stderr = open(os.devnull, "w")
-    match cli_args.action:
-        case CliAction.check:
-            return await check(cli_args)
     project_dir = await find_project_config_dir(cli_args.project_root or ".")
 
     try:
@@ -50,20 +55,23 @@ async def async_main():
         traceback.print_exception(e, file=sys.stderr)
         return 1
 
+    match cli_args.action:
+        case CliAction.check:
+            return await check(cli_args)
+        case CliAction.init:
+            return await init(cli_args)
+        case CliAction.version:
+            print(__version__)
+            return 0
+
     server_process = None
-    if not try_server(final_configs.host, final_configs.port):
+    if not await try_server(final_configs.host, final_configs.port):
         print(
             f"Host at {final_configs.host}:{final_configs.port} is unavailable. VectorCode will start its own Chromadb at a random port.",
             file=sys.stderr,
         )
         server_process = await start_server(final_configs)
 
-        def terminate():
-            server_process.terminate()
-            server_process.wait()
-
-        atexit.register(terminate)
-
     if final_configs.pipe:
         # NOTE: NNCF (intel GPU acceleration for sentence transformer) keeps showing logs.
         # This disables logs below ERROR so that it doesn't hurt the `pipe` output.
@@ -80,19 +88,23 @@ async def async_main():
                 return_val = await drop(final_configs)
             case CliAction.ls:
                 return_val = await ls(final_configs)
-            case CliAction.init:
-                return_val = await init(final_configs)
             case CliAction.update:
                 return_val = await update(final_configs)
-            case CliAction.version:
-                print(__version__)
-                return_val = 0
+            case CliAction.clean:
+                return_val = await clean(final_configs)
     except Exception as e:
         return_val = 1
         traceback.print_exception(e, file=sys.stderr)
     finally:
+        if server_process is not None:
+            server_process.terminate()
+            await server_process.wait()
         return return_val
 
 
 def main():
     return asyncio.run(async_main())
+
+
+if __name__ == "__main__":
+    sys.exit(main())
